@@ -479,13 +479,13 @@ def FieldDetermination(Fields,plot=False,**kwargs):
     if type(obj_color) == type(None):
       obj_color = 'r'
 
-    values = (data.iloc[2:,1:].values).astype(np.float)
-    lista1 = (data.iloc[0][1:].values +" - " + data.iloc[1][1:].values).tolist()
     null = 0
     fields = pd.DataFrame(columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
     circle = []
     rect = []
     if plot:
+        values = (data.iloc[2:,1:].values).astype(np.float)
+        lista1 = (data.iloc[0][1:].values +" - " + data.iloc[1][1:].values).tolist()
         ax = plt.gca()
         esquerda = values[:,lista1.index(bodyPartBox+" - x")].min()
         direita = values[:,lista1.index(bodyPartBox+" - x")].max()
@@ -959,7 +959,9 @@ def SignalSubset(sig_data,freq,fields, **kwargs):
     Notes
     -----
     This function was based using data from the electrophysiology plexon. Input data was formatted using
-    the LFP() function.""" 
+    the LFP() function0. Lista first index is to enter the list; Lista second index is to choose between
+    start([0]) ou end([1]); Lista third index is to choose between object/fields([0],[1] ...).
+    """ 
 
     start_time= kwargs.get('start_time')
     end_time = kwargs.get('end_time')
@@ -998,7 +1000,7 @@ def SignalSubset(sig_data,freq,fields, **kwargs):
                 lista.append((start,end))
 
         dicts = {}
-        keys = range(len(list(interação['obj'].unique())[1:]))
+        keys = range(len(list(fields['obj'].unique())[1:]))
 
         for j in keys:
             cortes = {}
